pub enum Error {
OutOfBounds,
NonUtf8String,
RequiredFieldMissing(&'static str),
NonNullTerminatedString,
UnknownEnumVariant,
UnknownUnionVariant,
NoTypeDefaultValue,
}Expand description
An error while accessing a flatbuffer
Variants
OutOfBounds
Returned if accessing the flatbuffer triggers an out-of-bounds access
NonUtf8String
Returned if a string is not UTF8
RequiredFieldMissing(&'static str)
Returned if a required field is missing
NonNullTerminatedString
Returned if a string is not null-terminated,
UnknownEnumVariant
Returned if a buffer refers to an unknown enum variant
UnknownUnionVariant
Returned if a buffer refers to an unknown union variant
NoTypeDefaultValue
Returned if a type doesn’t have a default value