pub struct SkipSizePrefix<T>(/* private fields */);Expand description
SkipSizePrefix is used by Follow to traverse a FlatBuffer: the pointer is incremented by a fixed constant in order to skip over the size prefix value.